"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.AylaDeviceApiService = void 0;
// Inspired by https://github.com/shawnjung/homebridge-plugin-dimplex-connex
const axios_1 = __importDefault(require("axios"));
const AuthToken_1 = require("./AuthToken");
class AylaDeviceApiService {
    /**
     * Ayla Networks API class
     *
     * implements AylaNetworks client, connects
     * to the AylaNetwork Services (EU)
     *
     * @param email: your Ayla Networks User username
     * @param password: your Ayla Networks User password
     */
    constructor(email, password) {
        this.authToken = new AuthToken_1.AuthToken({ email, password });
        this.client = this.initClient();
    }
    /**
     * Initializes the Api Client
     *
     * @returns an Axios Instance configured for the API endpoint
     */
    initClient() {
        const instance = axios_1.default.create({
            baseURL: 'https://ads-eu.aylanetworks.com/apiv1/',
            timeout: 10000,
            headers: {
                'Content-Type': 'application/json; charset=utf-8',
                Accept: 'application/json',
            },
        });
        instance.interceptors.request.use(async (request) => {
            if (!this.authToken.active) {
                await this.authToken.init();
            }
            else if (this.authToken.expired) {
                await this.authToken.refresh();
            }
            if (request.headers) {
                request.headers.Authorization = `auth_token ${this.authToken.getValue()}`;
            }
            return request;
        });
        return instance;
    }
    /**
     * Get all Oekoboiler Devices registered with the current user
     *
     * @returns a list of Oekboiler Devices
     */
    async getDevices() {
        const result = await this.client.get('devices');
        return result.data;
    }
    /**
     * Get all Oekoboiler Devices registered with the current user
     *
     * @param dsn: The DSN of the Oekoboiler Device.
     *                      Can be found by iterating over the device list
     *                      returned by {@link getDevices()}
     * @returns a list of Oekboiler Device
     *              Properties (see types.ts for the relevant fields)
     */
    async getDeviceProperties(dsn) {
        const result = await this.client.get(`dsns/${dsn}/properties`);
        return result.data;
    }
    /**
     * Update a specific device property See {@link Device}, {@link DeviceProperty} for details
     *
     * @param key the property key
     * @param value the property value
     */
    async updateDeviceProperty(key, value) {
        await this.client.post(`properties/${key}/datapoints`, {
            datapoint: { value },
        });
    }
}
exports.AylaDeviceApiService = AylaDeviceApiService;
//# sourceMappingURL=AylaDeviceService.js.map