"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.OekoboilerApi = void 0;
const AylaDeviceService_1 = require("./AylaDeviceService");
class OekoboilerApi {
    /**
     * Main Oekboiler Api Class
     *
     * implements an Oekoboiler Api client, connects
     * to the AylaNetwork Services (EU) and wraps it into
     *
     *
     * @param userEmail: your Oekoboiler App username
     * @param userPassword: your Oekoboiler App password
     */
    constructor(userEmail, userPassword) {
        this.attributeMap = {
            boilerOn: 'F104',
            alarm: 'F110',
            setWaterTemp: 'F11',
            temperatureDelta: 'F12',
            currentWaterTemp: 'F103',
            pvFunction: 'F62',
            version: 'version',
        };
        /**
         * Properties helper function
         *
         * @remarks
         * Returns key:value pair for a specific, named property
         *
         * @param name device property name
         * @param properties device properties
         * @returns device property key:value pair
         */
        this.getPropertyKeyAndValue = (name, properties) => {
            const deviceProperty = properties.find(({ property: p }) => p.name === name);
            if (!(deviceProperty === null || deviceProperty === void 0 ? void 0 : deviceProperty.property)) {
                return { value: '', key: -1 };
            }
            else {
                return {
                    value: deviceProperty.property.value,
                    key: deviceProperty.property.key,
                };
            }
        };
        /**
         * Helper function
         *
         * @remarks
         * folds the raw properties into a Oekboiler device
         *
         * @param properties array of a devices' raw properties
         * @returns an Oekoboiler device
         */
        this.getBoilerFromProperties = (properties) => {
            const boiler = Object.keys(this.attributeMap).reduce((acc, key) => {
                const { value } = this.getPropertyKeyAndValue(this.attributeMap[key], properties);
                Object.assign(acc, {
                    [key]: value,
                });
                return acc;
            }, {});
            return boiler;
        };
        this.aylaNetworkService = new AylaDeviceService_1.AylaDeviceApiService(userEmail, userPassword);
    }
    /**
     * Get Oekoboiler devices
     *
     * @returns Oekoboiler devices
     */
    getDevices() {
        return this.aylaNetworkService.getDevices();
    }
    /**
     *
     * @param key property key (See {@link Device})
     * @param value
     * @returns
     */
    async updateProperty(key, value) {
        return this.aylaNetworkService.updateDeviceProperty(key, value);
    }
    /**
     * Get Oekoboiler Data mapped into {@link OekoboilerDevice}
     *
     * @param dsn Boiler DSN
     * @returns an Oekoboiler properties type
     */
    async getBoiler(dsn) {
        const properties = await this.aylaNetworkService.getDeviceProperties(dsn);
        return this.getBoilerFromProperties(properties);
    }
}
exports.OekoboilerApi = OekoboilerApi;
//# sourceMappingURL=OekoboilerApi.js.map